==> dotnet_runtime-7.0.14.tar.gz: runtime-7.0.14/src/libraries/System.Private.Xml/tests/XmlSchema/XmlSchemaSet/TC_SchemaSet_XmlResolver.cs <==
// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

using Xunit;
using Xunit.Abstractions;
using System.IO;
using System.Xml.Schema;

namespace System.Xml.Tests
{
    //[TestCase(Name = "TC_SchemaSet_XmlResolver", Desc = "")]
    public class TC_SchemaSet_XmlResolver : TC_SchemaSetBase
    {
        private ITestOutputHelper _output;

        public TC_SchemaSet_XmlResolver(ITestOutputHelper output)
        {
            _output = output;
        }

        public bool bWarningCallback;

        public bool bErrorCallback;

        private void Initialize()
        {
            bWarningCallback = bErrorCallback = false;
        }

        //hook up validaton callback
        private void ValidationCallback(object sender, ValidationEventArgs args)
        {
            if (args.Severity == XmlSeverityType.Warning)
            {
                _output.WriteLine("WARNING: ");
                bWarningCallback = true;
            }
            else if (args.Severity == XmlSeverityType.Error)
            {
                _output.WriteLine("ERROR: ");
                bErrorCallback = true;
            }

            _output.WriteLine(args.Message); // Print the error to the screen.
        }

        //-----------------------------------------------------------------------------------
        //[Variation(Desc = "v1 - Resolver=NULL, add with URL", Priority = 1)]
        [Fact]
        public void v1()
        {
            try
            {
                XmlSchemaSet sc = new XmlSchemaSet();
                sc.ValidationEventHandler += new ValidationEventHandler(ValidationCallback);
                sc.XmlResolver = null;
                XmlSchema Schema = sc.Add(null, Path.Combine(TestData._Root, "XmlResolver", "File", "simpledtd.xml"));
            }
            catch (Exception)
            {
                return;
            }

            Assert.True(false);
        }

        //[Variation(Desc = "v2 - Resolver=NULL, add schema which imports schema on internet", Priority = 1)]
        [Fact]
        public void v2()
        {
            XmlSchemaSet sc = new XmlSchemaSet();
            sc.ValidationEventHandler += new ValidationEventHandler(ValidationCallback);
            sc.XmlResolver = null;
            sc.Add(null, Path.Combine(TestData._Root, "xmlresolver_v2.xsd"));
            CError.Compare(sc.Count, 1, "SchemaSet count");
            return;
        }

        //[Variation(Desc = "v3 - Resolver=Default, add schema which imports schema on internet", Priority = 1)]
        [Fact]
        public void v3()
        {
            XmlSchemaSet sc = new XmlSchemaSet();
            sc.ValidationEventHandler += new ValidationEventHandler(ValidationCallback);
            sc.Add(null, Path.Combine(TestData._Root, "xmlresolver_v2.xsd"));
            CError.Compare(sc.Count, 1, "SchemaSet count");
            return;
        }

        //[Variation(Desc = "v4 - schema(Local)->schema(Local)", Priority = 1)]
        [Fact]
        public void v4()
        {
            AppContext.SetSwitch("Switch.System.Xml.AllowDefaultResolver", true);

            Initialize();
            XmlSchemaSet sc = new XmlSchemaSet();
            sc.ValidationEventHandler += new ValidationEventHandler(ValidationCallback);
            sc.Add(null, Path.Combine(TestData._Root, "xmlresolver_v4.xsd"));
            CError.Compare(sc.Count, 2, "SchemaSet count");
            CError.Compare(bWarningCallback, false, "Warning thrown");
            return;
        }

        //[Variation(Desc = "v5 - schema(Local)->schema(Local)->schema(Local)", Priority = 1)]
        [Fact]
        public void v5()
        {
            AppContext.SetSwitch("Switch.System.Xml.AllowDefaultResolver", true);

            Initialize();
            XmlSchemaSet sc = new XmlSchemaSet();
            sc.ValidationEventHandler += new ValidationEventHandler(ValidationCallback);
            sc.Add(null, Path.Combine(TestData._Root, "xmlresolver_v5.xsd"));
            CError.Compare(sc.Count, 3, "SchemaSet count");
            CError.Compare(bWarningCallback, false, "Warning not thrown");
            return;
        }

        //[Variation(Desc = "v6 - schema(Local)->schema(Local), but resolving external URI is not allowed", Priority = 1)]
        [Fact]
        public void v6()
        {
            // Make sure the switch has its default value
            AppContext.SetSwitch("Switch.System.Xml.AllowDefaultResolver", false);

            Initialize();
            XmlSchemaSet sc = new XmlSchemaSet();
            sc.ValidationEventHandler += new ValidationEventHandler(ValidationCallback);
            sc.Add(null, Path.Combine(TestData._Root, "xmlresolver_v4.xsd"));
            CError.Compare(sc.Count, 1, "SchemaSet count");
            CError.Compare(bWarningCallback, false, "Warning thrown");
            return;
        }
    }
}

==> dotnet_runtime-8.0.7.tar.gz: runtime-8.0.7/src/libraries/System.Private.Xml/tests/XmlSchema/XmlSchemaSet/TC_SchemaSet_XmlResolver.cs <==
// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

using System.IO;
using System.Xml.Schema;
using System.Xml.Tests;
using Xunit;

namespace System.Xml.XmlSchemaTests
{
    //[TestCase(Name = "TC_SchemaSet_XmlResolver", Desc = "")]
    public class TC_SchemaSet_XmlResolver : TC_SchemaSetBase
    {
        //-----------------------------------------------------------------------------------
        //[Variation(Desc = "v1 - Resolver=NULL, add with URL", Priority = 1)]
        [Fact]
        public void v1()
        {
            try
            {
                XmlSchemaSet sc = new XmlSchemaSet();
                sc.ValidationEventHandler += new ValidationEventHandler((s, args) => { });
                sc.XmlResolver = null;
                XmlSchema Schema = sc.Add(null, Path.Combine(TestData._Root, "XmlResolver", "File", "simpledtd.xml"));
            }
            catch (Exception)
            {
                return;
            }

            Assert.True(false);
        }

        //[Variation(Desc = "v2 - Resolver=NULL, add schema which imports schema on internet", Priority = 1)]
        [Fact]
        public void v2()
        {
            XmlSchemaSet sc = new XmlSchemaSet();
            sc.ValidationEventHandler += new ValidationEventHandler((s, args) => { });
            sc.XmlResolver = null;
            sc.Add(null, Path.Combine(TestData._Root, "xmlresolver_v2.xsd"));
            CError.Compare(sc.Count, 1, "SchemaSet count");
        }

        //[Variation(Desc = "v3 - Resolver=Default, add schema which imports schema on internet", Priority = 1)]
        [Fact]
        public void v3()
        {
            XmlSchemaSet sc = new XmlSchemaSet();
            sc.ValidationEventHandler += new ValidationEventHandler((s, args) => { });
            sc.Add(null, Path.Combine(TestData._Root, "xmlresolver_v2.xsd"));
            CError.Compare(sc.Count, 1, "SchemaSet count");
        }

        //[Variation(Desc = "v4 - schema(Local)->schema(Local)", Priority = 1)]
        [Fact]
        public void v4()
        {
            using (new AllowDefaultResolverContext())
            {
                bool warningCallback = false;
                XmlSchemaSet sc = new XmlSchemaSet();
                sc.ValidationEventHandler += new ValidationEventHandler((s, args) => warningCallback |= args.Severity == XmlSeverityType.Warning);
                sc.Add(null, Path.Combine(TestData._Root, "xmlresolver_v4.xsd"));
                CError.Compare(sc.Count, 2, "SchemaSet count");
                CError.Compare(warningCallback, false, "Warning thrown");
            }
        }

        //[Variation(Desc = "v5 - schema(Local)->schema(Local)->schema(Local)", Priority = 1)]
        [Fact]
        public void v5()
        {
            using (new AllowDefaultResolverContext())
            {
                bool warningCallback = false;
                XmlSchemaSet sc = new XmlSchemaSet();
                sc.ValidationEventHandler += new ValidationEventHandler((s, args) => warningCallback |= args.Severity == XmlSeverityType.Warning);
                sc.Add(null, Path.Combine(TestData._Root, "xmlresolver_v5.xsd"));
                CError.Compare(sc.Count, 3, "SchemaSet count");
                CError.Compare(warningCallback, false, "Warning not thrown");
            }
        }

        //[Variation(Desc = "v6 - schema(Local)->schema(Local), but resolving external URI is not allowed", Priority = 1)]
        [Fact]
        public void v6()
        {
            bool warningCallback = false;
            XmlSchemaSet sc = new XmlSchemaSet();
            sc.ValidationEventHandler += new ValidationEventHandler((s, args) => warningCallback |= args.Severity == XmlSeverityType.Warning);
            sc.Add(null, Path.Combine(TestData._Root, "xmlresolver_v4.xsd"));
            CError.Compare(sc.Count, 1, "SchemaSet count");
            CError.Compare(warningCallback, false, "Warning thrown");
        }
    }
}
